Uses of Interface
org.sonar.java.checks.verifier.CheckVerifier
Packages that use CheckVerifier
-
Uses of CheckVerifier in org.sonar.java.checks.verifier
Methods in org.sonar.java.checks.verifier that return CheckVerifierModifier and TypeMethodDescriptionAdds a collection of files with an expected status to be verified by the given rule(s).CheckVerifier.addFiles(org.sonar.api.batch.fs.InputFile.Status status, Collection<String> filenames) Adds a collection of files with an expected status.static CheckVerifierCheckVerifier.newInternalVerifier()Deprecated, for removal: This API element is subject to removal in a future version.static CheckVerifierCheckVerifier.newVerifier()Entry point of check verification.Defines the filename to be verified with the given rule(s).Defines the filenames to be verified with the given rule(s).CheckVerifier.onFiles(Collection<String> filenames) Defines a collection of filenames to be verified with the given rule(s).CheckVerifier.withCache(org.sonar.api.batch.sensor.cache.ReadCache readCache, org.sonar.api.batch.sensor.cache.WriteCache writeCache) Tells the verifier to feed the check with cached information in its preScan phase.CheckVerifier.withCheck(JavaFileScanner check) Defines the check to be verified against at least one test file.CheckVerifier.withChecks(JavaFileScanner... checks) Defines the check(s) to be verified against at least one test file.CheckVerifier.withClassPath(Collection<File> classpath) Defines the classpath to be used for the verification.default CheckVerifierCheckVerifier.withCompilationUnitModifier(Consumer<CompilationUnitTree> compilationUnitModifier) Allows to modify the compilation unit tree after parsing.CheckVerifier.withinAndroidContext(boolean inAndroidContext) Defines whether the current file is an analyzer in an Android context.CheckVerifier.withJavaVersion(int javaVersionAsInt) Defines the java version syntax to be used for the verification.CheckVerifier.withJavaVersion(int javaVersionAsInt, boolean enablePreviewFeatures) Defines the java version syntax to be used for the verification.CheckVerifier.withoutSemantic()Tells the verifier that no bytecode will be provided.default CheckVerifierCheckVerifier.withProjectLevelWorkDir(String rootDirectory) Tells the verifier to feed the check with cached information in its preScan phase. -
Uses of CheckVerifier in org.sonar.java.checks.verifier.internal
Classes in org.sonar.java.checks.verifier.internal that implement CheckVerifierMethods in org.sonar.java.checks.verifier.internal that return CheckVerifierModifier and TypeMethodDescriptionJavaCheckVerifier.addFiles(org.sonar.api.batch.fs.InputFile.Status status, Collection<String> filenames) JavaCheckVerifier.onFiles(Collection<String> filenames) InternalCheckVerifier.withCache(org.sonar.api.batch.sensor.cache.ReadCache readCache, org.sonar.api.batch.sensor.cache.WriteCache writeCache) JavaCheckVerifier.withCache(org.sonar.api.batch.sensor.cache.ReadCache readCache, org.sonar.api.batch.sensor.cache.WriteCache writeCache) JavaCheckVerifier.withCheck(JavaFileScanner check) JavaCheckVerifier.withChecks(JavaFileScanner... checks) JavaCheckVerifier.withClassPath(Collection<File> classpath) JavaCheckVerifier.withCompilationUnitModifier(Consumer<CompilationUnitTree> compilationUnitModifier) InternalCheckVerifier.withinAndroidContext(boolean inAndroidContext) JavaCheckVerifier.withinAndroidContext(boolean inAndroidContext) JavaCheckVerifier.withJavaVersion(int javaVersionAsInt) JavaCheckVerifier.withJavaVersion(int javaVersionAsInt, boolean enablePreviewFeatures) JavaCheckVerifier.withoutSemantic()JavaCheckVerifier.withProjectLevelWorkDir(String rootDirectory)
newVerifier(), which uses the analyzer-commons-test-commons library to verify issues on checks.