Interface CheckVerifier

All Known Implementing Classes:
InternalCheckVerifier, JavaCheckVerifier

public interface CheckVerifier
This interface defines how to use checks (rules) verifiers. Its goal is to provide all the required information to the analyzer to verify the checks' expected behavior.

The starting point to define a verifier is newVerifier(). Then, a configuration can be specified.

It is required to provide to the verifier at least the following:

Methods starting with "verify..." (e.g verifyIssues() ) are the methods which effectively validate the rule. Any of them must be called at the end of the verifier's configuration to trigger the verification. Nothing will happen if one of these method is not called. It uses MultiFileVerifier from sonar-analyzer-commons - test-commons library to verify issues on file.