Uses of Class
org.sonar.java.checks.verifier.CheckVerifier
-
-
Uses of CheckVerifier in org.sonar.java.checks.verifier
Subclasses of CheckVerifier in org.sonar.java.checks.verifier Modifier and Type Class Description classJavaCheckVerifierIt is possible to specify the absolute line number on which the issue should appear by appending "@<line>" to "Noncompliant".classMultipleFilesJavaCheckVerifierPlease read the documentation of @see org.sonar.java.checks.verifier.JavaCheckVerifier The main difference is that this class run a check on multiple files and verifies the results at the end of analysis.classPomCheckVerifierclassXmlCheckVerifierMethods in org.sonar.java.checks.verifier with parameters of type CheckVerifier Modifier and Type Method Description protected static voidXmlCheckVerifier. retrieveExpectedIssuesFromFile(File xmlFile, CheckVerifier checkVerifier)Read the XML file using javax XMLStreamReader instead of SAX (used byXmlParser), as SAX does not provide any way to retrieve lines information of comments events.
-